package pro.litvinovg.w2phtml.gui;

import java.awt.Component;
import java.util.HashMap;
import java.util.Map;

import javax.swing.GroupLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.GroupLayout.Alignment;
import javax.swing.LayoutStyle.ComponentPlacement;

import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static pro.litvinovg.w2phtml.gui.Contstants.*;


public class PanelFactory {
	
	private Localizer localizer;
	private PreferencesStorage storage;
	private JTabbedPane tabbedPane;
	private static final Logger logger = LoggerFactory.getLogger(PanelFactory.class);

	public PanelFactory(Localizer localizer, PreferencesStorage storage,JTabbedPane tabbedPane) {
		this.localizer = localizer;
		this.storage = storage;
		this.tabbedPane = tabbedPane;
	}
	public JPanel createPanel(String name) {
		UIPreferences prefs = storage.get(name);
		String type = prefs.get(PREF_TYPE);
		JPanel panel = new JPanel();
		HashMap<String, Component> configuration = new HashMap<String, Component>();
		ControlPanel panel_control = new ControlPanel(configuration, storage, name, type);
		panel_control.setFactory(this);
		JPanel panel_configuration = null;
		if (EPUB.equals(type)){
			panel_configuration = new EpubPanel(configuration, storage.get(name));	
		} else if (RDF.equals(type)) {
			panel_configuration = new RDFPanel(configuration, storage.get(name));	
		} else {
			panel_configuration = new HTMLPanel(configuration, storage.get(name));	
		}
		applyDefaultLayout(panel, panel_configuration, panel_control);
		tabbedPane.addTab(name, null, panel, null);
		tabbedPane.setSelectedComponent(panel);
		return panel;
	}
	
	public void removeCurPanel() {
		tabbedPane.removeTabAt(tabbedPane.getSelectedIndex());
	}
	
	private void applyDefaultLayout(JPanel tabbedPanel, JPanel configPanel, JPanel controlPanel) {
		
		GroupLayout gl_panel_html = new GroupLayout(tabbedPanel);
		gl_panel_html.setHorizontalGroup(gl_panel_html.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_panel_html.createSequentialGroup().addGroup(gl_panel_html.createParallelGroup(Alignment.TRAILING)
						.addComponent(configPanel, GroupLayout.DEFAULT_SIZE, 852, Short.MAX_VALUE).addComponent(controlPanel, GroupLayout.DEFAULT_SIZE, 852, Short.MAX_VALUE)).addGap(4)));
		gl_panel_html.setVerticalGroup(gl_panel_html.createParallelGroup(Alignment.LEADING).addGroup(Alignment.TRAILING,
				gl_panel_html.createSequentialGroup()
				.addComponent(configPanel, GroupLayout.DEFAULT_SIZE, 691, Short.MAX_VALUE)
				.addPreferredGap(ComponentPlacement.RELATED)
				.addComponent(controlPanel, GroupLayout.PREFERRED_SIZE, 48, GroupLayout.PREFERRED_SIZE)));
		tabbedPanel.setLayout(gl_panel_html);
	}
	public void createPanels() {
		for (String name : storage.getTabNames()) {
			if (!name.equals(HTML)  && !name.equals(EPUB) && !name.equals(RDF)) {
				createPanel(name);
			}
		}		
	}
	
}
