package pro.litvinovg.w2phtml.gui;

import java.awt.Component;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.Map.Entry;

import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JTextField;

import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static pro.litvinovg.w2phtml.gui.Contstants.*;

public class UIPreferences {
	private static final Logger logger = LoggerFactory.getLogger(UIPreferences.class);

	private Map<String,String[]> prefs;
	
	private String sourceFileName = "";
	
	private boolean defaultTemplate = false;

	private PreferencesStorage storage;
	
	public void setDefault(boolean defaultTemplate) {
		this.defaultTemplate = defaultTemplate;
	}

	public UIPreferences(PreferencesStorage storage) {
		this.storage = storage;
		prefs = new HashMap<String,String[]>();
	}
			
	public UIPreferences(Map<String,String[]> sourcePrefs) {
		Iterator<Entry<String, String[]>> it = sourcePrefs.entrySet().iterator();
		prefs = new HashMap<String,String[]>();
		while (it.hasNext()) {
			Entry<String, String[]> pair = (Entry<String, String[]>) it.next();
			prefs.put(new String(pair.getKey()), Arrays.copyOf(pair.getValue(), pair.getValue().length));
		}
	}
	
	public void put(String name, String[]values) {
		prefs.put(name, values);
	}
	
	public void put(String name, String value) {
		prefs.put(name, new String[] {value});
	}
	
	
	public String getSourceFileName() {
		return sourceFileName;
	}

	public void setSourceFileName(String sourceFileName) {
		this.sourceFileName = sourceFileName;
	}
	
	public String[] getAll(String name) {
		if (prefs.containsKey(name)) {
			return prefs.get(name);
		} 
		if (defaultTemplate) {
			logger.error("Default preferences doesn't have values for " + name);
			return new String[]{""};
		}
		String[] type = prefs.get(PREF_TYPE);
		if (type == null) {
			logger.error("Tab preferences doesn't have type!");
			return new String[] {""};
		}
		if (storage == null) {
			logger.error("Storage is null");
			return new String[] {""};
		}
		UIPreferences defaultPreferences = storage.get(type[0]);
		return defaultPreferences.getAll(name);
	}
	
	public String get(String name) {
		return getAll(name)[0];
	}
	
	public UIPreferences clone() {
		UIPreferences clonedPrefs = new UIPreferences(prefs);
		clonedPrefs.setSourceFileName(sourceFileName);
		return clonedPrefs;
	}
	public void updateFrom(HashMap<String, Component> configuration) {
		Set<String> keys = configuration.keySet();
		for (String key : keys) {
			String value = null;
			Component component = configuration.get(key);
			if (component.getClass().equals(JTextField.class)) {
				value = ((JTextField) component).getText();
			} else if (component.getClass().equals(JCheckBox.class)) {
				value = Boolean.toString(((JCheckBox) component).isSelected());
			} else if (component.getClass().equals(JLabel.class)) {
				value = ((JLabel) component).getText();
			} else if (component.getClass().equals(JComboBox.class)) {
				value = Integer.toString(((JComboBox) component).getSelectedIndex());
			}
		prefs.put(key, new String[] {value});	
		}	
	}

	public JSONObject getJSON() {
		JSONObject prefObject = new JSONObject();
		for (Map.Entry<String, String[]> entry : prefs.entrySet()) {
			String name = entry.getKey();
			String[] values = entry.getValue();
			prefObject.put(name, values);
		}
		return prefObject;
	}
}
